# `jaxdf`

`jaxdf` is a customizable framework for writing differentiable simulators, that decouples the mathematical definition of the problem from the underlying discretization.

The underlying computations are performed using [JAX](https://github.com/google/jax), and are thus compatible with the broad set of program transformations, such as automatic differentiation and automatic batching. This enables rapid prototyping of multiple customized representations for a given problem, to develop physics-based neural network layers and to write custom physics losses, while maintaining the speed and flexibility required for research applications.

It also contains a growing open-source library of differentiable discretizations compatible with the JAX ecosystem.

</br>


### Tutorials

  - [Quickstart](notebooks/quickstart)
  - [Physics informed neural nerworks](notebooks/pinn_burgers/)
  - [Optimize acoustic simulations](notebooks/simulate_helmholtz_equation/)
  - [(⚠️ WIP) Discretization API](notebooks/api_discretization/)
  - [Solving the Helmholtz equation with PINNs](notebooks/helmholtz_pinn/)

</br>

### [**API Reference**](core)
